pub fn ffprobe<'a, T: IntoFfprobeArg<'a>>(
path: T,
) -> Result<FfProbe, FfProbeError>Expand description
Execute ffprobe with default settings and return the extracted data.
See ffprobe_config if you need to customize settings.
pub fn ffprobe<'a, T: IntoFfprobeArg<'a>>(
path: T,
) -> Result<FfProbe, FfProbeError>Execute ffprobe with default settings and return the extracted data.
See ffprobe_config if you need to customize settings.