pub struct AttachmentStream {
pub duration_ts: u64,
pub tags: AttachmentTags,
pub codec_long_name: Option<String>,
pub codec_name: Option<String>,
}Expand description
Stream of type attachment
Fields
duration_ts: u64Duration of the video stream in timestamp units.
Metadata tags associated with the video stream.
codec_long_name: Option<String>Long name of the codec used for the video stream.
codec_name: Option<String>Short name of the codec used for the video stream. Example: h264