pub struct DataStream {
pub duration_ts: u64,
pub tags: DataTags,
pub codec_long_name: Option<String>,
pub codec_name: Option<String>,
}Expand description
Stream of type data
Fields
duration_ts: u64Duration of the video stream in timestamp units.
Metadata tags associated with the video stream.
codec_long_name: Option<String>Long name of the codec used for the video stream. eg. binary data
codec_name: Option<String>Short name of the codec used for the video stream. Example: bin_data