AudioStream

Struct AudioStream 

pub struct AudioStream {
Show 13 fields pub bits_per_sample: i64, pub channel_layout: Option<String>, pub channels: i64, pub initial_padding: i64, pub sample_fmt: String, pub sample_rate: i64, pub bit_rate: Option<i64>, pub codec_long_name: String, pub codec_name: String, pub duration_ts: Option<u64>, pub profile: Option<String>, pub bits_per_raw_sample: Option<i64>, pub tags: Option<AudioTags>,
}
Stream of type audio

Fields

bits_per_sample: i64

The number of bits per sample in the audio stream.

channel_layout: Option<String>

The layout of audio channels. eg. stereo

channels: i64

number of channels eg. 2

initial_padding: i64

The initial padding in the audio stream. Padding in audio streams refers to extra bits or bytes added to the beginning of audio data to align it with specific boundaries or to provide some additional space for processing.

sample_fmt: String

The sample format of the audio stream. Smple format defines how each audio sample is represented in binary form. It describes the encoding method and the number of bits used to represent each sample.

Common sample formats include: s16: Signed 16-bit integer s32: Signed 32-bit integer flt: Floating point dbl: Double precision floating point todo: enum

sample_rate: i64

The sample rate of the audio stream. eg. 44100 Hz

bit_rate: Option<i64>

Bit rate of the video stream. The bit_rate represents the number of bits that are processed per unit of time in the video stream. It is a measure of the video stream’s data rate, indicating how much data is encoded for each second of video.

codec_long_name: String

Long name of the codec used for the video stream.

codec_name: String

Short name of the codec used for the video stream. Example: h264

duration_ts: Option<u64>

Duration of the video stream in timestamp units.

profile: Option<String>

Profile of the codec used for the video stream (e.g., Main, High).

bits_per_raw_sample: Option<i64>

This specifies the number of bits used to represent each component of the pixel. For example, in an 8-bit raw sample, each color component (e.g., red, green, and blue in an RGB format) is represented by 8 bits, allowing 256 different levels per component.

tags: Option<AudioTags>

Metadata tags associated with the video stream.